@@ -1,5 +1,5 @@
 # ------------------------------------------------------------------
-# Copyright (c) 2020 PyInstaller Development Team.
+# Copyright (c) 2024 PyInstaller Development Team.
 #
 # This file is distributed under the terms of the GNU General Public
 # License (version 2.0 or later).
@@ -2255,6 +2255,41 @@ def test_saml2(pyi_builder):
     """)
 
 
+# The prerequisite for this test is that tkinter can be used unfrozen, so try instantiating a window in a subprocess
+# to verify that this is the case. This check should cover the following scenarios:
+#  - tkinter missing
+#  - import of tkinter crashes python interpreter
+#  - tkinter.Tk() fails due to DISPLAY not being set on linux
+#  - tkinter.Tk() fails due to faulty build (e.g., due to Tcl/Tk version mix-up, as seen with python <= 3.10 builds on
+#    macos-12 GHA runners; https://github.com/actions/setup-python/issues/649#issuecomment-1745056485)
+def _tkinter_fully_usable():
+    from PyInstaller import isolated
+
+    @isolated.decorate
+    def _create_tkinter_window():
+        import tkinter
+        tkinter.Tk()
+
+    try:
+        _create_tkinter_window()
+    except Exception:
+        return False
+
+    return True
+
+
+@importorskip('sv_ttk')
+def test_sv_ttk(pyi_builder):
+    if not _tkinter_fully_usable():
+        pytest.skip("tkinter is not fully usable.")
+    pyi_builder.test_source("""
+        import sv_ttk
+
+        # Initialize sv_ttk to ensure it works correctly
+        sv_ttk.set_theme("dark")
+    """)
+
+
 @importorskip('toga')
 def test_toga(pyi_builder):
     pyi_builder.test_script(
@@ -2262,3 +2297,30 @@ def test_toga(pyi_builder):
         app_args=['--automatic-shutdown', '5'],
         pyi_args=['--windowed'] if is_darwin else [],
     )
+
+
+@importorskip('numbers_parser')
+def test_numbers_parser(pyi_builder, tmpdir):
+    output_filename = tmpdir / "output.numbers"
+    pyi_builder.test_source("""
+        import sys
+        import numbers_parser
+
+        output_filename = sys.argv[1]
+
+        doc = numbers_parser.Document()
+        doc.add_sheet("New Sheet", "New Table")
+        sheet = doc.sheets["New Sheet"]
+        table = sheet.tables["New Table"]
+        table.write(1, 1, 1000)
+        table.write(1, 2, 2000)
+        table.write(1, 3, 3000)
+        doc.save(output_filename)
+    """, app_args=[str(output_filename)])
+
+
+@importorskip('h3')
+def test_h3(pyi_builder):
+    pyi_builder.test_source("""
+        import h3
+    """)
